pecos.simulators.sparsesim.cmd\_one\_qubit
==========================================

.. automodule:: pecos.simulators.sparsesim.cmd_one_qubit







   .. rubric:: Functions

   .. autosummary::

      F
      F2
      F2dg
      F3
      F3dg
      F4
      F4dg
      Fdg
      H
      H2
      H3
      H4
      H5
      H6
      Identity
      SX
      SXdg
      SY
      SYdg
      SZ
      SZdg
      X
      Y
      Z
